==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/sr@latin.php <==
<?php $TRANSLATIONS = array(
"Wrong calendar" => "Pogrešan kalendar",
"Timezone changed" => "Vremenska zona je promenjena",
"Invalid request" => "Neispravan zahtev",
"Calendar" => "Kalendar",
"Birthday" => "Rođendan",
"Business" => "Posao",
"Call" => "Poziv",
"Clients" => "Klijenti",
"Deliverer" => "Dostavljač",
"Holidays" => "Praznici",
"Ideas" => "Ideje",
"Journey" => "putovanje",
"Jubilee" => "jubilej",
"Meeting" => "Sastanak",
"Other" => "Drugo",
"Personal" => "Lično",
"Projects" => "Projekti",
"Questions" => "Pitanja",
"Work" => "Posao",
"New Calendar" => "Novi kalendar",
"Does not repeat" => "Ne ponavlja se",
"Daily" => "dnevno",
"Weekly" => "nedeljno",
"Every Weekday" => "svakog dana u nedelji",
"Bi-Weekly" => "dvonedeljno",
"Monthly" => "mesečno",
"Yearly" => "godišnje",
"All day" => "Ceo dan",
"Title" => "Naslov",
"Week" => "Nedelja",
"Month" => "Mesec",
"List" => "Spisak",
"Today" => "Danas",
"CalDav Link" => "KalDav veza",
"Download" => "Preuzmi",
"Edit" => "Uredi",
"Delete" => "Obriši",
"New calendar" => "Novi kalendar",
"Edit calendar" => "Uredi kalendar",
"Displayname" => "Prikazanoime",
"Active" => "Aktivan",
"Calendar color" => "Boja kalendara",
"Save" => "Snimi",
"Submit" => "Pošalji",
"Cancel" => "Otkaži",
"Edit an event" => "Uredi događaj",
"Title of the Event" => "Naslov događaja",
"Category" => "Kategorija",
"All Day Event" => "Celodnevni događaj",
"From" => "Od",
"To" => "Do",
"Location" => "Lokacija",
"Location of the Event" => "Lokacija događaja",
"Description" => "Opis",
"Description of the Event" => "Opis događaja",
"Repeat" => "Ponavljaj",
"Create a new event" => "Napravi novi događaj",
"Timezone" => "Vremenska zona"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/sr@latin.php <==
<?php $TRANSLATIONS = array(
"Wrong calendar" => "Pogrešan kalendar",
"Timezone changed" => "Vremenska zona je promenjena",
"Invalid request" => "Neispravan zahtev",
"Calendar" => "Kalendar",
"Sunday" => "Nedelja",
"Monday" => "Ponedeljak",
"Tuesday" => "Utorak",
"Wednesday" => "Sreda",
"Thursday" => "Četvrtak",
"Friday" => "Petak",
"Saturday" => "Subota",
"Sun." => "Ned",
"Mon." => "Pon",
"Tue." => "Uto",
"Wed." => "Sre",
"Thu." => "Čet",
"Fri." => "Pet",
"Sat." => "Sub",
"January" => "Januar",
"February" => "Februar",
"March" => "Mart",
"April" => "April",
"May" => "Maj",
"June" => "Jun",
"July" => "Jul",
"August" => "Avgust",
"September" => "Septembar",
"October" => "Oktobar",
"November" => "Novembar",
"December" => "Decembar",
"Jan." => "Jan",
"Feb." => "Feb",
"Mar." => "Mar",
"Apr." => "Apr",
"May." => "Maj.",
"Jun." => "Jun",
"Jul." => "Jul",
"Aug." => "Avg",
"Sep." => "Sep",
"Oct." => "Okt",
"Nov." => "Nov",
"Dec." => "Dec",
"All day" => "Ceo dan",
"New Calendar" => "Novi kalendar",
"Title" => "Naslov",
"Birthday" => "Rođendan",
"Business" => "Posao",
"Call" => "Poziv",
"Clients" => "Klijenti",
"Deliverer" => "Dostavljač",
"Holidays" => "Praznici",
"Ideas" => "Ideje",
"Journey" => "putovanje",
"Jubilee" => "jubilej",
"Meeting" => "Sastanak",
"Other" => "Drugo",
"Personal" => "Lično",
"Projects" => "Projekti",
"Questions" => "Pitanja",
"Work" => "Posao",
"Does not repeat" => "Ne ponavlja se",
"Daily" => "dnevno",
"Weekly" => "nedeljno",
"Every Weekday" => "svakog dana u nedelji",
"Bi-Weekly" => "dvonedeljno",
"Monthly" => "mesečno",
"Yearly" => "godišnje",
"Week" => "Nedelja",
"Month" => "Mesec",
"List" => "Spisak",
"Today" => "Danas",
"Settings" => "Podešavanja",
"CalDav Link" => "KalDav veza",
"Download" => "Preuzmi",
"Edit" => "Uredi",
"Delete" => "Obriši",
"New calendar" => "Novi kalendar",
"Edit calendar" => "Uredi kalendar",
"Displayname" => "Prikazanoime",
"Active" => "Aktivan",
"Calendar color" => "Boja kalendara",
"Save" => "Snimi",
"Submit" => "Pošalji",
"Cancel" => "Otkaži",
"Edit an event" => "Uredi događaj",
"Title of the Event" => "Naslov događaja",
"Category" => "Kategorija",
"All Day Event" => "Celodnevni događaj",
"From" => "Od",
"To" => "Do",
"Location" => "Lokacija",
"Location of the Event" => "Lokacija događaja",
"Description" => "Opis",
"Description of the Event" => "Opis događaja",
"Repeat" => "Ponavljaj",
"Create a new event" => "Napravi novi događaj",
"Timezone" => "Vremenska zona"
);
